GSEA.ncbr_huse

GSEA.ncbr_huse

Set of functions supporting the FNL NCBR work

Author: Susan Huse

Created on Mon Aug 6 11:07:30 2018

Functions

Name Description
con_db Connect to the database.
err_out Exit with an error message.
fasta_count Count FASTA records in a file.
fasta_list List FASTA record identifiers.
pause_for_input Pause until the user provides a valid response.
run_cmd Run a shell command and capture its output.
run_os_cmd Run an operating-system command.
send_update Send a status update.
un_gzip Decompress a gzipped file.

con_db

GSEA.ncbr_huse.con_db(host_name, db_name, port_number)

Connect to the database.

err_out

GSEA.ncbr_huse.err_out(errMsg, log=None)

Exit with an error message.

fasta_count

GSEA.ncbr_huse.fasta_count(fastaFile)

Count FASTA records in a file.

fasta_list

GSEA.ncbr_huse.fasta_list(fastaFile)

List FASTA record identifiers.

pause_for_input

GSEA.ncbr_huse.pause_for_input(txt, contkey='y', quitkey='q', log=None)

Pause until the user provides a valid response.

run_cmd

GSEA.ncbr_huse.run_cmd(theCommand, fn, dorun)

Run a shell command and capture its output.

run_os_cmd

GSEA.ncbr_huse.run_os_cmd(theCommand, fn, dorun)

Run an operating-system command.

send_update

GSEA.ncbr_huse.send_update(updateStr, log=None, quiet=False)

Send a status update.

un_gzip

GSEA.ncbr_huse.un_gzip(fname, logfn)

Decompress a gzipped file.