hooks
hooks
Pre-commit hooks for CCBR Bioinformatics Software, intended for use with the pre-commit framework (https://pre-commit.com/).
hooks
Pre-commit hooks for CCBR Bioinformatics Software, intended for use with the pre-commit framework (https://pre-commit.com/).