homologfinder.hf
homologfinder.hf
Finds homologs in human and mouse.
About
hf or HomologFinder finds homologs in human and mouse. if the input gene or genelist is human, then it returns mouse homolog(s) and vice versa
Usage
$ hf -h
Examples
$ hf -g ZNF365
$ hf -l Wdr53,Zfp365
$ hf -f genelist.txt
Functions
| Name | Description |
|---|---|
| check_help | check if usage needs to be printed |
| collect_args | collect all the cli arguments |
| create_homolog_table | Create the homolog lookup table. |
| exit_w_msg | Gracefully exit with proper message |
| hf | Run the homolog finder lookup. |
| main | Run the CLI. |
| print_results | Print the homolog finder results. |
| process_args | Process CLI arguments into a gene list. |
| process_genelist | Expand a gene list with homologs from the lookup table. |
| read_lookup | Read the homolog lookup table. |
check_help
homologfinder.hf.check_help(parser)check if usage needs to be printed
collect_args
homologfinder.hf.collect_args()collect all the cli arguments
create_homolog_table
homologfinder.hf.create_homolog_table(
rpt_file=importlib.resources.files(__package__) / 'HOM_MouseHumanSequence.rpt',
)Create the homolog lookup table.
exit_w_msg
homologfinder.hf.exit_w_msg(message)Gracefully exit with proper message
hf
homologfinder.hf.hf(args)Run the homolog finder lookup.
main
homologfinder.hf.main()Run the CLI.
print_results
homologfinder.hf.print_results(result)Print the homolog finder results.
process_args
homologfinder.hf.process_args(args, lookup)Process CLI arguments into a gene list.
process_genelist
homologfinder.hf.process_genelist(gl, lookup)Expand a gene list with homologs from the lookup table.
read_lookup
homologfinder.hf.read_lookup()Read the homolog lookup table.